identity

package
v0.0.0-...-80bdd17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 10, 2026 License: BSD-3-Clause Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InstanceID

func InstanceID() <-chan string

InstanceID gets the instance id of this program invocation, if there is one. It may change if the program is suspended and resumed.

func PrincipalID

func PrincipalID() <-chan string

PrincipalID gets an id of this program instances's owner, if any. It may change if the program is suspended and resumed.

Types

This section is empty.

Jump to