Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InstanceID ¶
func InstanceID() <-chan string
InstanceID gets the instance id of this program invocation, if there is one. It may change if the program is suspended and resumed.
func PrincipalID ¶
func PrincipalID() <-chan string
PrincipalID gets an id of this program instances's owner, if any. It may change if the program is suspended and resumed.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.